use std::env;
use std::process::{self, Command};


fn main() {
    let global_matches = creddy_cli::parser().get_matches();
    let res = match global_matches.subcommand() {
        None | Some(("run", _)) => launch_gui(),
        Some(("get", m)) => creddy_cli::get(m, &global_matches),
        Some(("exec", m)) => creddy_cli::exec(m, &global_matches),
        Some(("shortcut", m)) => creddy_cli::invoke_shortcut(m, &global_matches),
        _ => unreachable!("Unknown subcommand"),
    };

    if let Err(e) = res {
        eprintln!("Error: {e}");
        process::exit(1);
    }
}


fn launch_gui() -> anyhow::Result<()>  {
    let mut path = env::current_exe()?;
    path.pop(); // bin dir

    // binaries are colocated in dev, but not in production
    #[cfg(not(debug_assertions))]
    path.pop(); // install dir

    path.push("creddy.exe"); // exe in main install dir (aka gui exe)

    Command::new(path).spawn()?;
    Ok(())
}
